diff --git a/src/pl/plpython/expected/plpython_trigger.out b/src/pl/plpython/expected/plpython_trigger.out
index 4148963..71f27f0 100644
--- a/src/pl/plpython/expected/plpython_trigger.out
+++ b/src/pl/plpython/expected/plpython_trigger.out
@@ -503,3 +503,20 @@ SELECT * FROM b;
  1234
 (1 row)
 
+-- check that SQL run in trigger code can see transition tables
+CREATE TABLE transition_table_test (id int, name text);
+INSERT INTO transition_table_test VALUES (1, 'a');
+CREATE FUNCTION transition_table_test_f() RETURNS trigger LANGUAGE plpythonu AS
+$$
+    rv = plpy.execute("SELECT * FROM old_table")
+    plpy.info("old: " + str(rv))
+    rv = plpy.execute("SELECT * FROM new_table")
+    plpy.info("new: " + str(rv))
+    return None
+$$;
+CREATE TRIGGER a_t AFTER UPDATE ON transition_table_test
+  REFERENCING OLD TABLE AS old_table NEW TABLE AS new_table
+  FOR EACH STATEMENT EXECUTE PROCEDURE transition_table_test_f();
+UPDATE transition_table_test SET name = 'b';
+INFO:  old: <PLyResult status=5 nrows=1 rows=[{'id': 1, 'name': 'a'}]>
+INFO:  new: <PLyResult status=5 nrows=1 rows=[{'id': 1, 'name': 'b'}]>
diff --git a/src/pl/plpython/plpy_exec.c b/src/pl/plpython/plpy_exec.c
index 697a0e1..65badb5 100644
--- a/src/pl/plpython/plpy_exec.c
+++ b/src/pl/plpython/plpy_exec.c
@@ -345,6 +345,33 @@ PLy_exec_trigger(FunctionCallInfo fcinfo, PLyProcedure *proc)
 
 	PG_TRY();
 	{
+		int rc;
+
+		if (tdata->tg_newtable)
+		{
+			rc = SPI_register_relation(tdata->tg_trigger->tgnewtable,
+									   tdata->tg_relation->rd_att,
+									   100,
+									   tdata->tg_newtable);
+			if (rc != SPI_OK_REGISTER)
+				elog(ERROR,
+					 "could not register relation \"%s\": %s",
+					 tdata->tg_trigger->tgnewtable,
+					 SPI_result_code_string(rc));
+		}
+		if (tdata->tg_oldtable)
+		{
+			rc = SPI_register_relation(tdata->tg_trigger->tgoldtable,
+								  tdata->tg_relation->rd_att,
+								  100,
+								  tdata->tg_oldtable);
+			if (rc != SPI_OK_REGISTER)
+				elog(ERROR,
+					 "could not register relation \"%s\": %s",
+					 tdata->tg_trigger->tgnewtable,
+					 SPI_result_code_string(rc));
+		}
+
 		plargs = PLy_trigger_build_args(fcinfo, proc, &rv);
 		plrv = PLy_procedure_call(proc, "TD", plargs);
 
diff --git a/src/pl/plpython/sql/plpython_trigger.sql b/src/pl/plpython/sql/plpython_trigger.sql
index a054fe7..4d06de8 100644
--- a/src/pl/plpython/sql/plpython_trigger.sql
+++ b/src/pl/plpython/sql/plpython_trigger.sql
@@ -406,3 +406,22 @@ SELECT * FROM a;
 DROP TABLE a;
 INSERT INTO b DEFAULT VALUES;
 SELECT * FROM b;
+
+-- check that SQL run in trigger code can see transition tables
+
+CREATE TABLE transition_table_test (id int, name text);
+INSERT INTO transition_table_test VALUES (1, 'a');
+
+CREATE FUNCTION transition_table_test_f() RETURNS trigger LANGUAGE plpythonu AS
+$$
+    rv = plpy.execute("SELECT * FROM old_table")
+    plpy.info("old: " + str(rv))
+    rv = plpy.execute("SELECT * FROM new_table")
+    plpy.info("new: " + str(rv))
+    return None
+$$;
+
+CREATE TRIGGER a_t AFTER UPDATE ON transition_table_test
+  REFERENCING OLD TABLE AS old_table NEW TABLE AS new_table
+  FOR EACH STATEMENT EXECUTE PROCEDURE transition_table_test_f();
+UPDATE transition_table_test SET name = 'b';
